[Bf-extensions-cvs] SVN commit: /data/svn/bf-extensions [3576] contrib/py/scripts/addons: Spellfixes: colour -> color

Bastien Montagne montagne29 at wanadoo.fr
Wed Jul 4 14:20:23 CEST 2012


Revision: 3576
          http://projects.blender.org/scm/viewvc.php?view=rev&root=bf-extensions&revision=3576
Author:   mont29
Date:     2012-07-04 12:20:22 +0000 (Wed, 04 Jul 2012)
Log Message:
-----------
Spellfixes: colour -> color

Modified Paths:
--------------
    contrib/py/scripts/addons/animation_motion_trail.py
    contrib/py/scripts/addons/io_export_marmalade.py

Modified: contrib/py/scripts/addons/animation_motion_trail.py
===================================================================
--- contrib/py/scripts/addons/io_export_marmalade.py	2012-07-04 12:20:09 UTC (rev 3575)
+++ contrib/py/scripts/addons/io_export_marmalade.py	2012-07-04 12:20:22 UTC (rev 3576)
@@ -707,9 +707,9 @@
             Normal = -Normal
         GeoModel.AddVertexNormal(Normal)
     #Check if some colors have been defined
-    vertexColours = None
+    vertexColors = None
     if Config.ExportVertexColors and (len(Mesh.vertex_colors) > 0):
-        vertexColours = Mesh.tessface_vertex_colors[0].data
+        vertexColors = Mesh.tessface_vertex_colors[0].data
 
     #Check if some uv coordinates have been defined
     UVCoordinates = None
@@ -726,8 +726,8 @@
         if Config.CoordinateSystem == 1:
             Vertices = Vertices[::-1]
         # stream for vertex colors
-        if vertexColours:
-            MeshColor = vertexColours[Face.index]
+        if vertexColors:
+            MeshColor = vertexColors[Face.index]
             if len(Vertices) == 3:
                 FaceColors = list((MeshColor.color1, MeshColor.color2, MeshColor.color3))
             else:



More information about the Bf-extensions-cvs mailing list
--- contrib/py/scripts/addons/animation_motion_trail.py	2012-07-04 12:20:09 UTC (rev 3575)
+++ contrib/py/scripts/addons/animation_motion_trail.py	2012-07-04 12:20:22 UTC (rev 3576)
@@ -274,7 +274,7 @@
         return
     
     # dictionaries with key: objectname
-    self.paths = {} # value: list of lists with x, y, colour
+    self.paths = {} # value: list of lists with x, y, color
     self.keyframes = {} # value: dict with frame as key and [x,y] as value
     self.handles = {} # value: dict of dicts
     self.timebeads = {} # value: dict with frame as key and [x,y] as value
@@ -365,7 +365,7 @@
                 speeds.append(dloc)
                 prev_loc = loc
         
         # calculate colour of path
         if context.window_manager.motion_trail.path_style == 'speed':
             speeds.sort()
             min_speed = speeds[0]
@@ -569,7 +569,7 @@
         # add frame positions to click-list
         if context.window_manager.motion_trail.frame_display:
             path = self.paths[display_ob.name]
-            for x, y, colour, frame, action_ob, child in path:
+            for x, y, color, frame, action_ob, child in path:
                 click.append([frame, "frame", mathutils.Vector([x,y]),
                     action_ob, child])
         
@@ -609,17 +609,17 @@
         bgl.glColor4f(0.0, 0.0, 0.0, alpha)
         for objectname, path in self.paths.items():
             bgl.glBegin(bgl.GL_LINE_STRIP)
-            for x, y, colour, frame, action_ob, child in path:
+            for x, y, color, frame, action_ob, child in path:
                 if frame < limit_min or frame > limit_max:
                     continue
                 bgl.glVertex2i(x, y)
             bgl.glEnd()
     else:
         for objectname, path in self.paths.items():
-            for i, [x, y, colour, frame, action_ob, child] in enumerate(path):
+            for i, [x, y, color, frame, action_ob, child] in enumerate(path):
                 if frame < limit_min or frame > limit_max:
                     continue
-                r, g, b = colour
+                r, g, b = color
                 if i != 0:
                     prev_path = path[i-1]
                     halfway = [(x + prev_path[0])/2, (y + prev_path[1])/2]
@@ -643,7 +643,7 @@
         bgl.glPointSize(1)
         bgl.glBegin(bgl.GL_POINTS)
         for objectname, path in self.paths.items():
-            for x, y, colour, frame, action_ob, child in path:
+            for x, y, color, frame, action_ob, child in path:
                 if frame < limit_min or frame > limit_max:
                     continue
                 if self.active_frame and objectname == self.active_frame[0] \
@@ -1693,7 +1693,7 @@
                 "acceleration"),
             ("simple", "Simple", "Black line"),
             ("speed", "Speed", "Gradient based on relative speed")),
-        description="Information conveyed by path colour",
+        description="Information conveyed by path color",
         default='simple',
         update=internal_update)
     path_transparency = bpy.props.IntProperty(name="Path transparency",
@@ -365,7 +365,7 @@
                 prev_loc = loc
         
-        # calculate colour of path
+        # calculate color of path
         if context.window_manager.motion_trail.path_style == 'speed':
             speeds.sort()

Modified: contrib/py/scripts/addons/io_export_marmalade.py
===================================================================